@@ -9,6 +9,8 @@
 
 #include <QObject>
 
+#include <memory>
+
 class DocumentManager;
 class FavoriteLocationModel;
 class HealthCertificateManager;
@@ -31,6 +33,7 @@ class Intent;
 }
 
 class QNetworkAccessManager;
+class QTemporaryDir;
 
 class ApplicationController : public QObject
 {
@@ -70,7 +73,11 @@ public:
 
     // data export
     Q_INVOKABLE void exportToFile(const QUrl &url);
+    Q_INVOKABLE void exportTripToFile(const QString &tripGroupId, const QUrl &url);
+    Q_INVOKABLE void exportTripToKDEConnect(const QString &tripGroupId, const QString &deviceId);
     Q_INVOKABLE void exportTripToGpx(const QString &tripGroupId, const QUrl &url);
+    Q_INVOKABLE void exportBatchToFile(const QString &batchId, const QUrl &url);
+    Q_INVOKABLE void exportBatchToKDEConnect(const QString &batchId, const QString &deviceId);
 
     // document attaching
     Q_INVOKABLE void addDocumentToReservation(const QString &batchId, const QUrl &url);
@@ -118,6 +125,9 @@ private:
     QString addDocumentFromFile(const QUrl &url);
     QString addAttachableDocument(const QString &fileName, const QByteArray &data);
 
+    bool exportTripToFile(const QString &tripGroupId, const QString &fileName);
+    bool exportBatchToFile(const QString &batchId, const QString &fileName);
+
     static ApplicationController *s_instance;
 
     ReservationManager *m_resMgr = nullptr;
@@ -131,6 +141,7 @@ private:
     mutable HealthCertificateManager *m_healthCertMgr = nullptr;
     std::function<QNetworkAccessManager*()> m_namFactory;
 
+    std::unique_ptr<QTemporaryDir> m_tempDir;
     bool m_importLock = false;
 };
 
