@@ -13,17 +13,20 @@ namespace Permission
 {
     Q_NAMESPACE
     enum Permission {
+        InvalidPermission, // captures QML errors resultin in "0" enum values
         ReadCalendar,
         WriteCalendar,
+        PostNotification,
     };
     Q_ENUM_NS(Permission)
 }
 
-/** Requesting platform permissions for access to controlled resources (calendar, location, etc). */
+/** Check and request platform permissions for access to controlled resources (calendar, location, etc). */
 class PermissionManager
 {
     Q_GADGET
 public:
+    Q_INVOKABLE static bool checkPermission(Permission::Permission permission);
     Q_INVOKABLE static void requestPermission(Permission::Permission permission, QJSValue callback);
 };
 
