@@ -8,6 +8,7 @@
 #include "reservationhelper.h"
 #include "logging.h"
 
+#include <KItinerary/BoatTrip>
 #include <KItinerary/BusTrip>
 #include <KItinerary/ExtractorPostprocessor>
 #include <KItinerary/Reservation>
@@ -58,6 +59,18 @@ bool PublicTransport::isBusMode(KPublicTransport::Line::Mode mode)
     }
 }
 
+bool PublicTransport::isBoatMode(KPublicTransport::Line::Mode mode)
+{
+    using namespace KPublicTransport;
+    switch (mode) {
+        case Line::Boat:
+        case Line::Ferry:
+            return true;
+        default:
+            return false;
+    }
+}
+
 KPublicTransport::Location PublicTransport::locationFromPlace(const QVariant& place, const QVariant &reservation)
 {
     using namespace KItinerary;
@@ -68,7 +81,9 @@ KPublicTransport::Location PublicTransport::locationFromPlace(const QVariant& pl
      || JsonLd::isA<BusReservation>(reservation) || JsonLd::isA<BoatReservation>(reservation)) {
         loc.setName(KItinerary::LocationUtil::name(place));
     }
-
+    if (JsonLd::isA<TrainReservation>(reservation) || JsonLd::isA<BusReservation>(reservation)) {
+        loc.setType(KPublicTransport::Location::Stop);
+    }
     const auto addr = KItinerary::LocationUtil::address(place);
     loc.setStreetAddress(addr.streetAddress());
     loc.setPostalCode(addr.postalCode());
@@ -306,6 +321,21 @@ static KItinerary::BusReservation applyJourneySection(KItinerary::BusReservation
     return res;
 }
 
+static KItinerary::BoatReservation applyJourneySection(KItinerary::BoatReservation res, const KPublicTransport::JourneySection &section)
+{
+    using namespace KItinerary;
+
+    auto trip = res.reservationFor().value<BoatTrip>();
+    trip.setDepartureTime(section.scheduledDepartureTime());
+    trip.setArrivalTime(section.scheduledArrivalTime());
+    // TODO ferry line name
+    trip.setDepartureBoatTerminal(PublicTransport::updateToLocation(trip.departureBoatTerminal(), section.from()));
+    trip.setArrivalBoatTerminal(PublicTransport::updateToLocation(trip.arrivalBoatTerminal(), section.to()));
+
+    res.setReservationFor(trip);
+    return res;
+}
+
 static QVariant postProcessOne(const QVariant &res)
 {
     KItinerary::ExtractorPostprocessor postProc;
@@ -326,6 +356,9 @@ QVariant PublicTransport::reservationFromJourneySection(const KPublicTransport::
     if (isBusMode(section.route().line().mode())) {
         return postProcessOne(::applyJourneySection(BusReservation(), section));
     }
+    if (isBoatMode(section.route().line().mode())) {
+        return postProcessOne(::applyJourneySection(BoatReservation(), section));
+    }
 
     qCWarning(Log) << "Unsupported section type:" << section.route().line().mode();
     return {};
@@ -341,6 +374,9 @@ QVariant PublicTransport::applyJourneySection(const QVariant &res, const KPublic
     if (JsonLd::isA<BusReservation>(res)) {
         return postProcessOne(::applyJourneySection(res.value<BusReservation>(), section));
     }
+    if (JsonLd::isA<BoatReservation>(res)) {
+        return postProcessOne(::applyJourneySection(res.value<BoatReservation>(), section));
+    }
 
     qCWarning(Log) << res.typeName() << "Unsupported section type!";
     return res;
@@ -596,4 +632,15 @@ KPublicTransport::Location PublicTransport::copyLocation(const KPublicTransport:
     return loc;
 }
 
+bool PublicTransport::isSameStopoverForLayout(const KPublicTransport::Stopover &lhs, const KPublicTransport::Stopover &rhs)
+{
+    if (!KPublicTransport::Stopover::isSame(lhs, rhs)) {
+        return false;
+    }
+
+    const auto lhsPlatform = lhs.hasExpectedPlatform() ? lhs.expectedPlatform() : lhs.scheduledPlatform();
+    const auto rhsPlatform = rhs.hasExpectedPlatform() ? rhs.expectedPlatform() : rhs.scheduledPlatform();
+    return lhsPlatform == rhsPlatform;
+}
+
 #include "moc_publictransport.cpp"
